package de.lmu.ifi.medien.ui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EtchedBorder;
import javax.swing.border.LineBorder;
import javax.swing.border.TitledBorder;

import de.lmu.ifi.medien.control.VideoController;

/**
 * The video frame. Nothing to do here!
 * @author Sebastian Boring
 */
public class VideoFrame extends JFrame {
	private static final long serialVersionUID = -8072339679258254354L;
	
	private VideoController control;
	
	public VideoFrame(VideoController control)
	{
		this.control = control;
		
		setTitle("Live \"Lower Third\" Effect");
		addWindowListener(new WindowAdapter()
		{
			public void windowClosing(WindowEvent evt)
			{
				VideoFrame.this.control.shutdown(0);
			}
		});
		
		getContentPane().setLayout(new BorderLayout(2, 2));
	}
	
	public void addControlComponent(Component control)
	{
		if(control != null)
		{
			JPanel controlPanel = new JPanel(new BorderLayout(5, 5));
			controlPanel.setBorder(new TitledBorder(new EtchedBorder(EtchedBorder.LOWERED), "Video Control"));
			controlPanel.add(control);
			
			getContentPane().add(controlPanel, BorderLayout.SOUTH);
		}
	}

	public void addVisualComponent(Component visual)
	{
		if(visual != null)
		{
			JPanel visualPanel = new JPanel(new BorderLayout(0, 0));
			visualPanel.setBorder(new LineBorder(Color.BLACK, 1));
			visualPanel.setSize(new Dimension(visual.getWidth() + 2, visual.getHeight() + 2));
			visualPanel.add(visual, BorderLayout.CENTER);
			
			JPanel borderPanel = new JPanel(new BorderLayout(5, 5));
			borderPanel.setBorder(new TitledBorder(new EtchedBorder(EtchedBorder.LOWERED), "Video Window"));
			borderPanel.add(visualPanel);
			
			getContentPane().add(borderPanel, BorderLayout.CENTER);
		}
	}
	
	public void addCodecComponent(Component codec)
	{
		if(codec != null)
		{
			JPanel codecPanel = new JPanel(new FlowLayout(FlowLayout.LEFT, 2, 2));
			codecPanel.setBorder(new TitledBorder(new EtchedBorder(EtchedBorder.LOWERED), "Overlay Control"));
			codecPanel.add(codec);
			
			getContentPane().add(codecPanel, BorderLayout.EAST);
		}
	}
}
